<?php

namespace apexl\Io\modules\display\components;

use apexl\Io\modules\component\entities\componentEntity;

class FormComponent extends componentEntity
{
    public function __construct()
    {
        parent::__construct();
        $this->header(5);
        $this->setColWidth('md', 12);
        $this->setName('Form');
    }

    public function src($src)
    {
        $this->addProperty('dataSrc', $src);
        return $this;
    }

    public function header($num)
    {
        $this->addProperty('header', $num);
        return $this;
    }

    public function title($title)
    {
        if ($title) {
            $this->addProperty('title', $title);
        }
        return $this;
    }
}
