<?php

namespace apexl\Io\modules\display\regions;

use apexl\Io\modules\display\components\TheLeftSidebar;
use apexl\Io\modules\display\includes\region;

class LeftSideBarRegion extends region
{
    public function setRegionWrapper(): void
    {
        $this->regionComponent = new TheLeftSidebar();
    }
}
